@@ -14,7 +14,7 @@ HeaderParser::~HeaderParser( void )
 {
 }
 
-bool HeaderParser::parse( const char *buf, size_t bufEnd, int *headerend, int *bodystart, int *bodylength )
+bool HeaderParser::parse( const QString &buf, size_t bufEnd, int *headerend, int *bodystart, int *bodylength )
 {
 	size_t pos   = 0;
 	size_t start = 0;
