@@ -23,6 +23,7 @@
 #define HEADERPARSER_H_INCLUDED
 
 #include <sys/types.h>
+#include <qstring.h>
 
 /**
  * Container class for the header parsing function used by dissipate.  This
@@ -38,7 +39,7 @@ public:
 	 * Returns the position where the header ends, the body begins, and the
 	 * length of the body of the header.
 	 */
-	static bool parse( const char *buf, size_t bufEnd, int *headerend,
+	static bool parse( const QString &buf, size_t bufEnd, int *headerend,
 		int *bodystart, int *bodylength );
 };
 
