@@ -415,7 +415,7 @@ void SipCallMember::handlingInviteResponse( void )
 	if( state == state_Connected ) {
 		if( local->getStatus().getCode() >= 200 ) {
 			if( local->getStatus().getCode() == 200 ) {
-				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + tr(local->getStatus().getReasonPhrase());
 				statusUpdated( this );
 			} else if( local->getStatus().getCode() == 407 ) {
 				proxyauthstr = local->getFinalProxyAuthString();
@@ -430,7 +430,7 @@ void SipCallMember::handlingInviteResponse( void )
 				return;
 			} else {
 				state = state_Disconnected;
-				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + tr(local->getStatus().getReasonPhrase());
 			}
 			op = opIdle;
 			local = 0;
@@ -451,7 +451,7 @@ void SipCallMember::handlingInviteResponse( void )
 
 			} else {
 				state = state_Disconnected;
-				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + tr(local->getStatus().getReasonPhrase());
 			}
 			op = opIdle;
 			local = 0;
@@ -474,10 +474,10 @@ void SipCallMember::handlingInviteResponse( void )
 			if( local->getStatus().getCode() < 300 ) {
 				call->setCallStatus( SipCall::callInProgress );
 				state = state_Connected;
-				statusdesc = tr("Connected: ") + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Connected: ") + tr(local->getStatus().getReasonPhrase());
 			} else if( local->getStatus().getCode() < 400 ) {
 				state = state_Redirected;
-				statusdesc = tr("Redirected: ") + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Redirected: ") + tr(local->getStatus().getReasonPhrase());
 				redirectlist = local->getFinalContactList();
 			} else {
 				if(local->getStatus().getCode() == 407){
@@ -500,13 +500,13 @@ void SipCallMember::handlingInviteResponse( void )
 
 				} else {
 					state = state_Disconnected;
-					statusdesc = "!!" + tr("Call Failed: ") + local->getStatus().getReasonPhrase();
+					statusdesc = "!!" + tr("Call Failed: ") + tr(local->getStatus().getReasonPhrase());
 				}
 			}
 			op = opIdle;
 			local = 0;
 		} else {
-			statusdesc = local->getStatus().getReasonPhrase();
+			statusdesc = tr(local->getStatus().getReasonPhrase());
 			if( local->getStatus().getCode() != 100 ) {
 				state = state_EarlyDialog;
 			}
