@@ -1351,7 +1351,7 @@ void SipClient::setCallForwardMessage( const QString &newmessage )
 
 const QString SipClient::getUserAgent( void )
 {
-	return "kphone/4.1.1";
+	return "kphone/4.2";
 }
 
 void SipClient::setMaxForwards( int newmax )
