@@ -213,13 +213,13 @@ void SipMessage::parseHeaders( const QString &inbuf )
 	year = month = day = hour = min = sec = 0;
 	lastheader = 0;
 	for (;;) {
-		if( !HeaderParser::parse( inbuf.utf8().mid( lastheader ).data(),
-			inbuf.utf8().mid( lastheader ).length(), &headerend, &bodystart, &bodylength ) ) {
+		if( !HeaderParser::parse( inbuf.mid( lastheader ).data(),
+			inbuf.mid( lastheader ).length(), &headerend, &bodystart, &bodylength ) ) {
 			break;
 		}
-		curheader = inbuf.utf8().mid( lastheader, headerend ).simplifyWhiteSpace();
+		curheader = inbuf.mid( lastheader, headerend ).simplifyWhiteSpace();
 		curbody = inbuf.mid( lastheader + bodystart, bodylength ).simplifyWhiteSpace();
-		id = SipHeader::matchHeader( curheader.utf8() );
+		id = SipHeader::matchHeader( curheader );
 		if ( id == SipHeader::Via ) {
 			vialist.parseVia( curbody );
 		} else if( id == SipHeader::Expires ) {
@@ -378,7 +378,7 @@ void SipMessage::parseHeaders( const QString &inbuf )
 			}
 		}
 		lastheader += bodystart + bodylength;
-		if ( lastheader >= inbuf.utf8().length() ) {
+		if ( lastheader >= inbuf.length() ) {
 			break;
 		}
 	}
