@@ -41,6 +41,11 @@ QString SipTransaction::getCSeq( void ) const
 	return cseq;
 }
 
+QString SipTransaction::getSeqMethod( void ) const
+{ 
+	return Sip::getMethodString( requestmessage->getMethod() );
+}
+
 void SipTransaction::setStatus( const SipStatus &stat )
 {
 	laststatus = stat;
@@ -268,7 +273,7 @@ void SipTransaction::incomingRequest( SipMessage *message )
 				optsdp.setName( "session" );
 				optsdp.setPort( 0 );
 				optsdp.setVideoPort( 0 );
-				sendResponse( SipStatus( 200 ), optsdp.message( codecULAW, codecUnknown ),
+				sendResponse( SipStatus( 200 ), optsdp.message( codecPCMU, codecUnknown ),
 					MimeContentType( "application/sdp" ) );
 				break;
 			case Sip::MSG:
