@@ -91,6 +91,11 @@ public:
 	 */
 	unsigned int getSeqNum( void ) const { return seqnum; }
 
+	/**
+	 * Returns the Method part of the CSeq for this transaction.
+	 */
+	QString getSeqMethod( void ) const;
+
 	/**
 	 * Returns the current status of this transaction.
 	 */
