@@ -37,6 +37,7 @@ const QString SipVia::getTransportString( Transport t )
 	switch ( t ) {
 		case UDP: return "UDP";
 		case TCP: return "TCP";
+		case TLS: return "TLS";
 		case BadTransport: return "BAD";
 	}
 	return QString::null;
@@ -46,6 +47,7 @@ SipVia::Transport SipVia::matchTransport( const QString t )
 {
 	if ( t.compare( getTransportString( UDP ) ) == 0 ) { return UDP; }
 	if ( t.compare( getTransportString( TCP ) ) == 0 ) { return TCP; };
+	if ( t.compare( getTransportString( TLS ) ) == 0 ) { return TLS; };
 
 	return BadTransport;
 }
