@@ -51,6 +51,11 @@ const SipVia &SipViaList::getTopmostVia( void )
 	return vialist[ 0 ];
 }
 
+const SipVia &SipViaList::getBottommostVia( void )
+{
+	return vialist.last();
+}
+
 bool SipViaList::isValid( void )
 {
 	QValueList<SipVia>::Iterator it;
