@@ -38,7 +38,7 @@ AudioControl::AudioControl( QWidget *parent, const char *name )
 	bg4->insert( jackButton, jack );
 	connect( jackButton, SIGNAL( clicked() ), this, SLOT( jackButtonClicked() ) );
 #endif
-
+	QSettings settings;
 	bg2 = new QHButtonGroup( tr("OSS Device Mode"), vbox );
 	rwButton = new QRadioButton( tr("ReadWrite"), bg2 );
 	bg2->insert( rwButton, rw );
@@ -46,14 +46,11 @@ AudioControl::AudioControl( QWidget *parent, const char *name )
 	bg2->insert( rowoButton, rowo );
 	connect( rwButton, SIGNAL( clicked() ), this, SLOT( rwButtonClicked() ) );
 	connect( rowoButton, SIGNAL( clicked() ), this, SLOT( rowoButtonClicked() ) );
-	QSettings settings;
-	QString dev = settings.readEntry( "/kphone/audio/oss-filename" );
-	QString dev2 = settings.readEntry( "/kphone/audio/oss-filename2" );
 	(void) new QLabel( tr("Device for WriteOnly or ReadWrite:"), vbox );
-	dspdev = new QLineEdit( dev, vbox );
+	dspdev = new QLineEdit( vbox );
 	dspdev->setMinimumWidth( fontMetrics().maxWidth() * 20 );
 	(void) new QLabel( tr("Device for ReadOnly:"), vbox );
-	dspdev2 = new QLineEdit( dev2, vbox );
+	dspdev2 = new QLineEdit( vbox );
 	dspdev2->setMinimumWidth( fontMetrics().maxWidth() * 20 );
 	bg1 = new QHButtonGroup( tr("Preferred Codec"), vbox );
 	pcmuButton = new QRadioButton( tr("G711u"), bg1 );
@@ -69,34 +66,29 @@ AudioControl::AudioControl( QWidget *parent, const char *name )
 	connect( gsmButton, SIGNAL( clicked() ), this, SLOT( gsmButtonClicked() ) );
 	connect( ilbcButton, SIGNAL( clicked() ), this, SLOT( ilbcButtonClicked() ) );
 
+	QString mode = settings.readEntry( "/kphone/audio/mode", "readwrite" );
+	if( mode == "readwrite" ) {
+		rwButton->setChecked(TRUE);
+	} else {
+		rowoButton->setChecked(TRUE);
+	}
+
 #ifdef ALSA_SUPPORT
 	QString audiomode = settings.readEntry( "/kphone/audio/audio", "alsa" );
 	if( audiomode == "alsa" ) {
 		alsaButton->setChecked(TRUE);
-		rwButton->setEnabled(FALSE);
-		rowoButton->setEnabled(FALSE);
-		dspdev->setEnabled(FALSE);
-		dspdev2->setEnabled(FALSE);
+		alsaButtonClicked();
 #ifdef JACK_SUPPORT
 	} else if( audiomode == "jack" ) {
 		jackButton->setChecked(TRUE);
-		rwButton->setEnabled(FALSE);
-		rowoButton->setEnabled(FALSE);
-		dspdev->setEnabled(FALSE);
-		dspdev2->setEnabled(FALSE);
+		jackButtonClicked();
 #endif
 	} else {
 		ossButton->setChecked(TRUE);
-		rwButton->setEnabled(TRUE);
-		QString mode = settings.readEntry( "/kphone/audio/mode", "readwrite" );
-		if( mode == "readwrite" ) {
-			rwButton->setChecked(TRUE);
-			dspdev2->setEnabled(FALSE);
-		} else {
-			rowoButton->setChecked(TRUE);
-			dspdev2->setEnabled(TRUE);
-		}
+		ossButtonClicked();
 	}
+#else
+	ossButtonClicked();
 #endif
 
 	QString codec = settings.readEntry( "/kphone/audio/Codec", "PCMU" );
@@ -192,18 +184,25 @@ void AudioControl::ossButtonClicked( void )
 	} else {
 		dspdev2->setEnabled(TRUE);
 	}
+	QSettings settings;
+	dspdev->setText( settings.readEntry( "/kphone/audio/oss-filename", "/dev/dsp" ) );
+	dspdev2->setText( settings.readEntry( "/kphone/audio/oss-filename2" ) );
 }
 
 void AudioControl::alsaButtonClicked( void )
 {
 	bg2->setEnabled(FALSE);
-	dspdev->setEnabled(FALSE);
+	dspdev->setEnabled(TRUE);
 	dspdev2->setEnabled(FALSE);
+	QSettings settings;
+	dspdev->setText( settings.readEntry( "/kphone/audio/alsa-devicename", "default" ) );
 }
 
 void AudioControl::jackButtonClicked( void )
 {
 	bg2->setEnabled(FALSE);
+	rwButton->setEnabled(FALSE);
+	rowoButton->setEnabled(FALSE);
 	dspdev->setEnabled(FALSE);
 	dspdev2->setEnabled(FALSE);
 }
@@ -302,13 +301,19 @@ void AudioControl::slotApply( void )
 #endif
 		case alsa:
 			settings.writeEntry( "/kphone/audio/audio", "alsa");
+			settings.writeEntry( "/kphone/audio/alsa-devicename", dspdev->text() );
 			break;
 		case oss:
 			settings.writeEntry( "/kphone/audio/audio", "oss");
+			settings.writeEntry( "/kphone/audio/oss-filename", dspdev->text() );
+			settings.writeEntry( "/kphone/audio/oss-filename2", dspdev2->text() );
 			break;
 	}
+#else
+	settings.writeEntry( "/kphone/audio/audio", "oss");
+	settings.writeEntry( "/kphone/audio/oss-filename", dspdev->text() );
+	settings.writeEntry( "/kphone/audio/oss-filename2", dspdev2->text() );
 #endif
-
 	int payload;
 	switch( bg3->id( bg3->selected() ) ) {
 		case size80:
