@@ -41,6 +41,7 @@ CallAudio::CallAudio(  KPhoneView *phoneview )
 	audiomode = oss;
 	setOSSFilename( QString::null );
 	setOSSFilename2( QString::null );
+	setALSADevicename( QString::null );
 	setVideoSW( QString::null );
 	local.setIpAddress( "0.0.0.0" );
 	QSettings settings;
@@ -108,6 +109,15 @@ void CallAudio::setOSSFilename2( const QString &devname )
 	}
 }
 
+void CallAudio::setALSADevicename( const QString &devname )
+{
+	if( devname == QString::null ) {
+		alsadevicename = "default";
+	} else {
+		alsadevicename = devname;
+	}
+}
+
 void CallAudio::setVideoSW( const QString &sw )
 {
 	if( sw == QString::null ) {
@@ -174,7 +184,7 @@ void CallAudio::audioIn( void )
 		outrtp->setPortNum( portnum );
 		outrtp->openDevice( DspOut::WriteOnly );
 		outrtp->setPayload( payload );
-		DspOutAlsa *inaudio = new DspOutAlsa();
+		DspOutAlsa *inaudio = new DspOutAlsa( alsadevicename );
 		QSettings settings;
 		printf( "CallAudio: Opening ALSA device for Input \n" );
 		if( !inaudio->openDevice( DspOut::ReadOnly ) ) {
@@ -314,7 +324,7 @@ SdpMessage CallAudio::audioOut( void )
 		inrtp->openDevice( DspOut::ReadOnly );
 		local.setPort( inrtp->getPortNum() );
 		local.setVideoPort( inrtp->getVideoPortNum() );
-		DspOutAlsa *outalsa = new DspOutAlsa();
+		DspOutAlsa *outalsa = new DspOutAlsa( alsadevicename );
 		QSettings settings;
 		printf( "CallAudio: Opening ALSA device for Output\n" );
 		if( !outalsa->openDevice( DspOut::WriteOnly )){
@@ -395,6 +405,7 @@ void CallAudio::readAudioSettings( void )
 	QSettings settings;
 	setOSSFilename( settings.readEntry( "/kphone/audio/oss-filename" ) );
 	setOSSFilename2( settings.readEntry( "/kphone/audio/oss-filename2" ) );
+	setALSADevicename( settings.readEntry( "/kphone/audio/alsa-devicename" ) );
 	if( settings.readEntry( "/kphone/Symmetric/Media", "Yes" ) == "Yes" ) {
 		setSymMediaMode( true );
 	}
