@@ -1,8 +1,8 @@
 #include "dspout.h"
 
 DspOut::DspOut( void )
+:devstate(DeviceClosed)
 {
-	devstate = DeviceClosed;
 }
 
 DspOut::~DspOut( void )
