@@ -189,7 +189,8 @@ bool DspOutAlsa::writeBuffer( void )
 #ifdef ALSADEBUG
 			fprintf(stderr,  "write %d instead of %d frames !\n", rc, (int)count/2);
 #endif
-			(int8_t*) buf += rc*4;
+			int8_t *buff = (int8_t*) buf;
+			buff += rc*4;
 			count -= rc*2;
 			continue;
 		}
