@@ -9,9 +9,9 @@ class DspOutAlsa : public DspOut
 public:
 	/**
 	 * Constructs a DspOutAlsa object representing the given
-	 * filename.  Default is /dev/dsp.
+	 * filename.  Default is default.
 	 */
-	DspOutAlsa( const QString &fileName = "plughw:0,0" );
+	DspOutAlsa( const QString &fileName = "default" ); //Changed by bobosch
 
 	/**
 	 * Destructor.  Will close the device if it is open.
