@@ -39,6 +39,14 @@ DspOutRtp::DspOutRtp( const codecType newCodec, int newCodecNum, const QString &
 	, useStun(false)
 	, destroySocket(false)
 {
+	#ifdef SRTP
+	QSettings settings;
+	if(settings.readEntry("/kphone/SRTP/Enable", "") == "Yes"){
+		wrapper = SRTPWrapper::getInstance();
+	} else{
+		wrapper = 0;	
+	}
+	#endif
 	codec = newCodec;
 	codecNum = newCodecNum;
 	if (s) {
@@ -83,6 +91,11 @@ DspOutRtp::~DspOutRtp( void )
 	delete[] static_cast<unsigned char *>( tmpbuf );
 	delete[] static_cast<unsigned char *>( quebuf );
 	if (destroySocket) delete socket;
+	#ifdef SRTP
+	if(!wrapper == 0){
+		wrapper->dispose();
+	}
+	#endif
 }
 
 bool DspOutRtp::openDevice( DeviceMode mode )
@@ -185,7 +198,15 @@ bool DspOutRtp::writeBuffer( void )
 			for( int i = 0; i < tmpsize; ++i ) {
 				databuf[ i ] = outbuf[ i ];
 			}
+			#ifdef SRTP
+			int* length = new int(sizeof( rtp_hdr_t ) + tmpsize);
+			if(!wrapper == 0){
+				wrapper->protect(packetbuf, length);
+			}
+			if( socket->send( (char *) packetbuf, *length) < 0 ) {
+			#else
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + tmpsize ) < 0 ) {
+			#endif
 				printf("DspOutRtp::writeBuffer: %s\n", strerror(errno));
 				return false;
 			}
@@ -224,7 +245,15 @@ bool DspOutRtp::writeBuffer( void )
 			for( int i = 0; i < tmpsize; ++i ) {
 				databuf[ i ] = outbuf[ i ];
 			}
+			#ifdef SRTP
+			int* length = new int(sizeof( rtp_hdr_t ) + tmpsize);
+			if(!wrapper == 0){
+				wrapper->protect(packetbuf, length);
+			}
+			if( socket->send( (char *) packetbuf, *length) < 0 ) {
+			#else
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + tmpsize ) < 0 ) {
+			#endif
 				printf("DspOutRtp::writeBuffer: %s\n", strerror(errno));
 				return false;
 			}
@@ -277,7 +306,15 @@ bool DspOutRtp::writeBuffer( void )
 				--bytesnew;
 				++bytesgot;
 			}
+			#ifdef SRTP
+			int* length = new int(sizeof( rtp_hdr_t ) + fixedrtplen);
+			if(!wrapper == 0){
+				wrapper->protect(packetbuf, length);
+			}
+			if( socket->send( (char *) packetbuf, *length ) < 0 ) {
+			#else
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + fixedrtplen ) < 0 ) {
+			#endif
 				printf("DspOutRtp::writeBuffer: %s\n", strerror(errno));
 				return false;
 			}
@@ -339,6 +376,13 @@ bool DspOutRtp::readBuffer( int bytes )
 	int size;
 	recvsize = socket->receive( (char *) packetbuf, sizeof( rtp_hdr_t ) + dsize );
 	rtp_hdr_t *h = (rtp_hdr_t *) packetbuf;
+	#ifdef SRTP
+	if(!wrapper == 0){
+		int* length = new int(recvsize);
+		wrapper->unprotect(packetbuf, length);
+		recvsize = *length;
+	}
+	#endif
 	if( h->pt == PCMUCODEC ) {
 		audio_buf.resize( ( recvsize - (int) sizeof( rtp_hdr_t ) ) * sizeof( short ) );
 		outbuf = (short *) audio_buf.getData();
