@@ -1,5 +1,5 @@
 /*
- * $Id: dtmfgenerator.cpp,v 1.1.1.1 2005/04/18 13:04:40 pera Exp $
+ * $Id: dtmfgenerator.cpp,v 1.2 2005/05/18 07:06:14 pera Exp $
  *
  * (c) 2003 iptel.org
  *
@@ -43,21 +43,7 @@ const DTMFGenerator::DTMFTone DTMFGenerator::tones[NUM_TONES] = {
 	{'C', 852, 1633},
 	{'D', 941, 1633},
 	{'*', 941, 1209},
-	{'E', 941, 1209},
-	{'e', 941, 1209},
-	{'#', 941, 1477},
-	{'F', 941, 1477},
-	{'f', 941, 1477},
-	{'a', 697, 1633},
-	{'b', 770, 1633},
-	{'c', 852, 1633},
-	{'d', 941, 1633},
-	{'X', 20, 20},
-	{'x', 20, 20},
-	{'Y', 100, 100},
-	{'y', 100, 100},
-	{'Z', 500, 500},
-	{'z', 500, 500},
+	{'#', 941, 1477}
 };
 
 
