@@ -1,3 +1,7 @@
+/*
+ * PCMA PCMU Codec
+ */
+
 #include <g711.h>
 
 static unsigned short u2s[] = {
@@ -606,8 +610,11 @@ static inline int val_seg(int val)
 	return r;
 }
 
+/*
+ * PCMU (ulaw)
+ */
 
-unsigned char linear2ulaw( short sample )
+unsigned char linear2ulaw( int sample )
 {
 	return S2U( (unsigned short) sample );
 }
@@ -645,3 +652,57 @@ short ulaw2linear( unsigned char ulawbyte )
 }
 
 
+/*
+ * PCMA (alaw)
+ *
+ * linear2pcma() - Convert a 16-bit linear PCM to an (PCMA) A-law
+ *
+ * context is copyed from gstream plugin
+ */
+
+unsigned char linear2pcma(int pcm_val)
+{
+	int             mask;
+	int             seg;
+	unsigned char   aval;
+
+	if (pcm_val >= 0) {
+		mask = 0xd5;
+	} else {
+		mask = 0x55;
+		pcm_val = -pcm_val;
+		if (pcm_val > 0x7fff)
+			pcm_val = 0x7fff;
+	}
+
+	if (pcm_val < 256)
+		aval = pcm_val >> 4;
+	else {
+		/* Convert the scaled magnitude to segment number. */
+		seg = val_seg(pcm_val);
+		aval = (seg << 4) | ((pcm_val >> (seg + 3)) & 0x0f);
+	}
+	return aval ^ mask;
+}
+
+/*
+ *   pcma2linear() - Convert an (PCMA) A-law value to 16-bit linear PCM
+ *  
+ */
+int pcma2linear(unsigned char a_val)
+{
+	int             t;
+	int             seg;
+
+	a_val ^= 0x55;
+	t = a_val & 0x7f;
+	if (t < 16)
+		t = (t << 4) + 8;
+	else {
+		seg = (t >> 4) & 0x07;
+		t = ((t & 0x0f) << 4) + 0x108;
+		t <<= seg -1;
+	}
+	return ((a_val & 0x80) ? t : -t);
+}
+
