@@ -11,6 +11,7 @@
 #include <qpushbutton.h>
 #include <qtextedit.h>
 #include <qsettings.h>
+#include <qspinbox.h>
 #include <qdir.h>
 #include <qmessagebox.h>
 #include <sys/soundcard.h>
@@ -87,10 +88,14 @@ void KCallTransfer::slotCancel( void )
 	QDialog::reject();
 }
 
-KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCall *initcall,
-		QWidget *parent, const char *name )
-	: QDialog( parent, name, FALSE, WStyle_DialogBorder ), call( initcall )
+KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCall *initcall, KPhoneView *parent, const char *name )
+	: call( initcall ), phoneView( parent )
 {
+	if( call->getSubject() == tr("Incoming call") )
+		QDialog::QDialog( NULL, name, FALSE, WStyle_DialogBorder );
+	else
+		QDialog::QDialog( parent, name, FALSE, WStyle_DialogBorder );
+		
 	sipauthentication = auth;
 	missedCalls.setAutoDelete( true );
 	receivedCalls.setAutoDelete( true );
@@ -116,6 +121,10 @@ KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCal
 	connect( acceptCallTimer, SIGNAL( timeout() ),
 		this, SLOT( acceptCallTimeout() ) );
 
+	dtmfsenderTimer = new QTimer();
+	connect( dtmfsenderTimer, SIGNAL( timeout() ),
+		this, SLOT( dtmfsenderTimeout() ) );
+
 	QVBoxLayout *vbox = new QVBoxLayout( this );
 	vbox->setMargin( 3 );
 	vbox->setSpacing( 3 );
@@ -135,6 +144,20 @@ KCallWidget::KCallWidget( KSipAuthentication *auth, CallAudio *callaudio, SipCal
 
 	headergrid->addWidget( remote, 0, 1 );
 
+	// DTMF Sender
+	QLabel *dtmfsenderlabel = new QLabel( tr("Send DTMF: "), this );
+	dtmfsenderlabel->setFixedWidth(
+		dtmfsenderlabel->fontMetrics().width( tr("  Send DTMF:  ")  ) );
+	headergrid->addWidget( dtmfsenderlabel, 1, 0 );
+	dtmfsender = new QComboBox( true, this );
+	dtmfsender->setAutoCompletion( true );
+    connect( dtmfsender, SIGNAL( textChanged(const QString &) ),
+        this, SLOT( dtmfsenderChanged(const QString &) ) );
+	headergrid->addWidget( dtmfsender, 1, 1 );
+	dtmfsenderdelay = new QSpinBox( 5, 300, 5, this);
+	dtmfsenderdelay->setValue(10);
+	headergrid->addWidget( dtmfsenderdelay, 1, 2 );
+
 	// Remember to give remote completion
 	int count = 0;
 	QString s;
@@ -274,24 +297,32 @@ void KCallWidget::createKeypad(void)
 {
 	QGrid* grid;
 	setOrientation(Qt::Vertical);
-	grid = new QGrid(3);
+	grid = new QGrid(4);
 	grid->setMargin(30);
 	keypad = new QButtonGroup();
 	keypad->insert(new QPushButton("1\n ", grid));
 	keypad->insert(new QPushButton("2\nABC", grid));
 	keypad->insert(new QPushButton("3\nDEF", grid));
+	keypad->insert(new QPushButton("a\n ", grid));
 	keypad->insert(new QPushButton("4\nGHI", grid));
 	keypad->insert(new QPushButton("5\nJKL", grid));
 	keypad->insert(new QPushButton("6\nMNO", grid));
+	keypad->insert(new QPushButton("b\n ", grid));
 	keypad->insert(new QPushButton("7\nPQRS", grid));
 	keypad->insert(new QPushButton("8\nTUV", grid));
 	keypad->insert(new QPushButton("9\nWXYZ", grid));
-	keypad->insert(new QPushButton("*\n ", grid));
+	keypad->insert(new QPushButton("c\n ", grid));
+	keypad->insert(new QPushButton("e\n*", grid));
 	keypad->insert(new QPushButton("0\n ", grid));
-	keypad->insert(new QPushButton("#\n ", grid));
+	keypad->insert(new QPushButton("f\n#", grid));
+	keypad->insert(new QPushButton("d\n ", grid));
+	keypad->insert(new QPushButton("x\n ", grid));
+	keypad->insert(new QPushButton("y\n ", grid));
+	keypad->insert(new QPushButton("z\n ", grid));
 	connect(keypad, SIGNAL( pressed(int) ), this, SLOT( keypadPressed(int) ));
 	connect(keypad, SIGNAL( released(int) ), this, SLOT( keypadReleased(int) ));
 	setExtension(grid);
+
 }
 
 void KCallWidget::keypadPressed( int id )
@@ -301,15 +332,22 @@ void KCallWidget::keypadPressed( int id )
 		case 0: code = '1'; break;
 		case 1: code = '2'; break;
 		case 2: code = '3'; break;
-		case 3: code = '4'; break;
-		case 4: code = '5'; break;
-		case 5: code = '6'; break;
-		case 6: code = '7'; break;
-		case 7: code = '8'; break;
-		case 8: code = '9'; break;
-		case 9: code = '*'; break;
-		case 10: code = '0'; break;
-		case 11: code = '#'; break;
+		case 3: code = 'a'; break;
+		case 4: code = '4'; break;
+		case 5: code = '5'; break;
+		case 6: code = '6'; break;
+		case 7: code = 'b'; break;
+		case 8: code = '7'; break;
+		case 9: code = '8'; break;
+		case 10: code = '9'; break;
+		case 11: code = 'c'; break;
+		case 12: code = '*'; break;
+		case 13: code = '0'; break;
+		case 14: code = '#'; break;
+		case 15: code = 'd'; break;
+		case 16: code = 'x'; break;
+		case 17: code = 'y'; break;
+		case 18: code = 'z'; break;
 	}
 	audio->startDTMF(code);
 }
@@ -400,6 +438,8 @@ void KCallWidget::switchCall( SipCall *newcall )
 			dial->setEnabled( false );
 			hangup->setEnabled( true );
 			curstate = Connected;
+			if (!dtmfsenderTimer->isActive())
+				dtmfsenderTimer->start(dtmfsenderdelay->value() * 10);
 		}
 	} else {
 		curstat->setText( QString::null );
@@ -519,7 +559,8 @@ void KCallWidget::callMemberStatusUpdated( void )
 				member->getLocalStatusDescription().remove(0,2) );
 			setHide();
 		} else {
-			curstat->setText( member->getLocalStatusDescription() );
+			curstat->setText( member->getLocalStatusDescription()
+					+ " at " + QDateTime::currentDateTime().toString("hh:mm:ss"));
 		}
 		forceDisconnect();
 	} else if( member->getState() == SipCallMember::state_Redirected ) {
@@ -535,6 +576,8 @@ void KCallWidget::callMemberStatusUpdated( void )
 		dial->setEnabled( false );
 		hangup->setEnabled( true );
 		curstate = Connected;
+		if (!dtmfsenderTimer->isActive())
+			dtmfsenderTimer->start(dtmfsenderdelay->value() * 10);
 	} else {
 		curstat->setText( member->getLocalStatusDescription() );
 	}
@@ -582,6 +625,8 @@ void KCallWidget::acceptCall( void )
 
 void KCallWidget::holdCall( void )
 {
+    if( curstate != Connected ) 
+		return;
 	if( audio->getCurrentCall() == call ) {
 		audio->toggleOnHold();
 		holdbutton->setText( tr("Unhold") );
@@ -662,7 +707,11 @@ void KCallWidget::forceDisconnect( void )
 	call = 0;
 	callDeleted();
 	ringTimer->stop();
-	setHide();
+	dial->setEnabled(false);
+	hangup->setEnabled(false);
+	holdbutton->setEnabled(false);
+	transferbutton->setEnabled(false);
+	morebutton->setEnabled(false);
 }
 
 void KCallWidget::updateAudioStatus( void )
@@ -696,7 +745,7 @@ void KCallWidget::pleaseDial( const SipUri &dialuri )
 void KCallWidget::showTransferDialog( void )
 {
 	if( !transfer ) {
-		transfer = new KCallTransfer;
+		transfer = new KCallTransfer(this);
 		connect( transfer, SIGNAL( pleaseTransfer( const QString & ) ),
 			this, SLOT( pleaseTransfer( const QString & ) ) );
 	}
@@ -724,6 +773,11 @@ void KCallWidget::pleaseTransfer( const QString &transferto )
 	}
 }
 
+void KCallWidget::setDTMFSender( QString &s )
+{
+	dtmfsender->setCurrentText(s);
+}
+
 void KCallWidget::getUri( void )
 {
 	QSettings settings;
@@ -743,7 +797,7 @@ void KCallWidget::getUri( void )
 	}
 	phoneBook->exec();
 	remote->setEditText( phoneBook->getUri() );
-	((KPhoneView *)parentWidget())->updateContacts( xmlFile );
+	phoneView->updateContacts( xmlFile );
 }
 
 void KCallWidget::updateCallRegister( void )
@@ -812,6 +866,54 @@ void KCallWidget::updateCallRegister( void )
 	}
 }
 
+void KCallWidget::dtmfsenderChanged ( const QString &s )
+{
+	printf("dtmfsenderChanged\n");
+	if (!dtmfsenderTimer->isActive())
+		dtmfsenderTimer->start(dtmfsenderdelay->value() * 10);
+}
+
+void KCallWidget::dtmfsenderTimeout( void )
+{
+	char c;
+	
+	printf("dtmfsenderTimeout\n");
+	if (dtmfsender->currentText().length() == 0 || curstate != Connected)
+		dtmfsenderTimer->stop();
+	else {
+		c = dtmfsender->currentText().at(0).latin1();
+		dtmfsenderTimer->changeInterval(dtmfsenderdelay->value() * 10);
+		
+		switch (c) {
+		case '0':	case '1':	case '2':	case '3':	case '4':
+		case '5':	case '6':	case '7':	case '8':	case '9':
+		case '#':	case '*':	case 'A':	case 'a':	case 'B':
+		case 'b':	case 'C':	case 'c':	case 'D':	case 'd':
+		case 'X':	case 'x':	case 'Y':	case 'y':	case 'Z':
+		case 'z':
+			audio->startDTMF(c);
+			dtmfsender->setCurrentText(dtmfsender->currentText().mid(1).prepend('w'));
+			break;
+		case 'W':
+			audio->stopDTMF();
+			dtmfsender->setCurrentText(dtmfsender->currentText().mid(1).prepend('w'));
+			break;
+		case 'w':
+			audio->stopDTMF();
+			dtmfsender->setCurrentText(dtmfsender->currentText().mid(1));
+			break;
+		case ' ':	case '-':	case '(':	case ')':
+			/* Quick-pause */
+			dtmfsender->setCurrentText(dtmfsender->currentText().mid(1));
+			dtmfsenderTimer->changeInterval(1);
+			break;
+		case '/':
+		default:
+			/* This blocks DTMF... */
+			dtmfsenderTimer->stop();
+		}
+	}
+}
 
 void KCallWidget::ringTimeout( void )
 {
@@ -925,7 +1027,7 @@ void KCallWidget::hideCall( void )
 
 QString KCallWidget::getUserPrefix( void )
 {
-	return ((KPhone *)parentWidget()->parentWidget())->getUserPrefix();
+	return ((KPhone *)phoneView->parentWidget())->getUserPrefix();
 }
 
 void KCallWidget::setHide( void )
