@@ -314,10 +314,10 @@ void KPhone::toggleVisibility()
 void KPhone::trayMenuRequested( const QPoint& pos )
 {
 	QPopupMenu* trayMenu = new QPopupMenu(this);
-	trayMenu->insertItem( isVisible() ? "&Hide" : "S&how", this, SLOT( toggleVisibility() ) );
+	trayMenu->insertItem( isVisible() ? tr("&Hide") : tr("S&how"), this, SLOT( toggleVisibility() ) );
 	trayMenu->insertItem( view->getState() ? "&Offline" : "&Online" , view, SLOT( buttonOffOnlineClicked() ) );
 	trayMenu->insertSeparator();
-	trayMenu->insertItem( "&Quit", this, SLOT( kphoneQuit() ) );
+	trayMenu->insertItem( tr("&Quit"), this, SLOT( kphoneQuit() ) );
 	trayMenu->exec(pos);
 	delete trayMenu;
 }
