@@ -192,7 +192,7 @@ QString PhoneBookEditIdentity::getContact( void )
 
 void PhoneBookEditIdentity::setContact( QString newContact )
 {
-	if( newContact.lower() == "yes" ) {
+	if( newContact == QObject::tr("Yes") ) {
 		contact->setChecked( true );
 	} else {
 		contact->setChecked( false );
@@ -271,16 +271,16 @@ PhoneBookParser::PhoneBookParser( QListView * t, bool CallRegister, bool rejecte
 	listReceivedCalls = 0;
 	listMissedCalls = 0;
 	if( rejectedContact ) {
-		rejected = new QListViewItem( t, "Permanently rejected contacts", "" );
+		rejected = new QListViewItem( t, QObject::tr("Permanently rejected contacts"), "" );
 	}
 	if( CallRegister ) {
 		QListViewItem *item;
-		item = new QListViewItem( t, "Call Register", "" );
+		item = new QListViewItem( t, QObject::tr("Call Register"), "" );
 		item->setOpen( TRUE );
-		listReceivedCalls = new QListViewItem( item, "Received calls", "" );
-		listMissedCalls = new QListViewItem( item, "Missed calls", "" );
+		listReceivedCalls = new QListViewItem( item, QObject::tr("Received calls"), "" );
+		listMissedCalls = new QListViewItem( item, QObject::tr("Missed calls"), "" );
 	}
-	listPhoneBook = new QListViewItem( t, "PhoneBook", "" );
+	listPhoneBook = new QListViewItem( t, QObject::tr("PhoneBook"), "" );
 	listPhoneBook->setOpen( TRUE );
 }
 
@@ -311,7 +311,7 @@ bool PhoneBookParser::startElement( const QString&, const QString&,
 			contact = "No";
 		}
 		if( !stack.isEmpty() ) {
-			new QListViewItem( stack.top(), uri, contact, description );
+			new QListViewItem( stack.top(), uri, QObject::tr(contact), description );
 		}
 	}
 	return TRUE;
@@ -496,10 +496,10 @@ void PhoneBook::addContact( SipCallMember *member )
 		}
 		personItem->setOpen( TRUE );
 		if( !identityFound ) {
-			new QListViewItem( personItem, identity, addIdentity->getContact(), addIdentity->getDescription() );
+			new QListViewItem( personItem, identity, QObject::tr(addIdentity->getContact()), addIdentity->getDescription() );
 		} else {
 			if( identityItem ) {
-				identityItem->setText( 1, addIdentity->getContact() );
+				identityItem->setText( 1, QObject::tr(addIdentity->getContact()) );
 				identityItem->setText( 2, addIdentity->getDescription() );
 			}
 		}
@@ -521,15 +521,15 @@ void PhoneBook::clickAddButton()
 	if( item != 0 ) {
 		if( item->parent() != 0 ) {
 			if( item->parent()->parent() == 0 ) {
-				if( item->parent()->text( 0 ) == "Permanently rejected contacts" ) {
+				if( item->parent()->text( 0 ) == QObject::tr("Permanently rejected contacts") ) {
 					return;
 				}
-				if( item->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					addIdentity->setPerson( item->text( 0 ) );
 				}
 			} else {
 				if( item->parent()->parent()->parent() == 0 ) {
-					if( item->parent()->parent()->text( 0 ) == "PhoneBook" ) {
+					if( item->parent()->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 						addIdentity->setPerson( item->parent()->text( 0 ) );
 					}
 				}
@@ -554,7 +554,7 @@ void PhoneBook::clickAddButton()
 			item = new QListViewItem( parser->getListPhoneBook(), addIdentity->getPerson(), "" );
 		}
 		item->setOpen( TRUE );
-		new QListViewItem( item, s, addIdentity->getContact(), addIdentity->getDescription() );
+		new QListViewItem( item, s, QObject::tr(addIdentity->getContact()), addIdentity->getDescription() );
 	}
 	save();
 }
@@ -567,7 +567,7 @@ void PhoneBook::clickEditButton()
 	if( item != 0 ) {
 		if( item->parent() != 0 ) {
 			if( item->parent()->parent() == 0 ) {
-				if( item->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					if( !editPerson ) {
 						editPerson = new PhoneBookEditPerson( this, caption );
 					}
@@ -578,7 +578,7 @@ void PhoneBook::clickEditButton()
 					}
 				}
 			} else if( item->parent()->parent()->parent() == 0 ) {
-				if( item->parent()->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					if( !editIdentity ) {
 						editIdentity = new PhoneBookEditIdentity( this, caption );
 					}
@@ -593,7 +593,7 @@ void PhoneBook::clickEditButton()
 						} else {
 							item->setText( 0, s );
 						}
-						item->setText( 1, editIdentity->getContact() );
+						item->setText( 1, QObject::tr(editIdentity->getContact()) );
 						item->setText( 2, editIdentity->getDescription() );
 					}
 				}
@@ -613,18 +613,18 @@ void PhoneBook::clickRemoveButton()
 	if( item != 0 ) {
 		if( item->parent() != 0 ) {
 			if( item->parent()->parent() == 0 ) {
-				if( item->parent()->text( 0 ) == "Permanently rejected contacts" ) {
+				if( item->parent()->text( 0 ) == QObject::tr("Permanently rejected contacts") ) {
 					OK = true;
 				}
-				if( item->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					OK = true;
 				}
 			} else if( item->parent()->parent()->parent() == 0 ) {
-				if( item->parent()->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					OK = true;
 				}
 			} else if( item->parent()->parent()->parent()->parent() == 0 ) {
-				if( item->parent()->parent()->parent()->text( 0 ) == "PhoneBook" ) {
+				if( item->parent()->parent()->parent()->text( 0 ) == QObject::tr("PhoneBook") ) {
 					OK = true;
 				}
 			}
