@@ -44,7 +44,7 @@ bool ContactParser::startElement( const QString&, const QString&,
 		if( uri.left( 4 ).lower() != "tel:" && uri.left( 4 ).lower() != "sip:" ) {
 			uri = "sip:" + uri;
 		}
-		if( contact.lower() != "no" ) {
+		if( contact != QObject::tr("No") ) {
 			if( !description.isEmpty() ) {
 				uri += ";" + description;
 			}
@@ -389,6 +389,9 @@ void KPhoneView::contactDoubleClicked( QListViewItem *i )
 	QString subject = ( (ContactsListViewItem *) i )->getCall()->getSubject();
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
 	newcall->setSubject( user->getUri().uri() );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
@@ -494,7 +497,7 @@ void KPhoneView::showPhoneBook()
 	QPtrList<IncomingCall> r;
 	QPtrList<IncomingCall> m;
 	PhoneBook *phoneBook = new PhoneBook(file, this, getUserPrefix() +
-		"Phone Book", r, m, rejectedContactList );
+		tr("Phone Book"), r, m, rejectedContactList );
 	phoneBook->exec();
 	rejectedContactList = phoneBook->getRejectedContactsList();
 	saveRejectContactList();
