@@ -15,7 +15,8 @@ class KSipAuthenticationRequest : public QDialog
 	Q_OBJECT
 public:
 	KSipAuthenticationRequest( const QString &server, const QString &sipuri,
-		const QString &caption, QWidget *parent = 0, const char *name = 0 );
+		const QString &prefix, const QString &authtype, 
+		QWidget *parent = 0, const char *name = 0 );
 	~KSipAuthenticationRequest( void );
 	void setUsername( const QString &newUsername );
 	void setPassword( const QString &newPassword );
@@ -31,6 +32,7 @@ private:
 	QLineEdit *password;
 	QPushButton *okPushButton;
 	QPushButton *cancelPushButton;
+	QString userPrefix;
 };
 
 class KSipAuthentication : public QObject
