@@ -5,6 +5,7 @@
 
 #include "../dissipate2/sipclient.h"
 #include "callaudio.h"
+#include "../config.h"
 
 class QLineEdit;
 class QMultiLineEdit;
@@ -30,6 +31,9 @@ private:
 	enum Stun { stunYes, stunNo };
 	enum Symmetric { symmetricYes, symmetricNo };
 	enum SymMedia { symMediaYes, symMediaNo };
+	#ifdef SRTP
+	enum Srtp { enableSRTP, disableSRTP };
+	#endif
 	
 	SipClient *c;
 	CallAudio *audio;
@@ -52,6 +56,10 @@ private:
 	QButtonGroup *socket;
 	QLineEdit *mediaMinPort;
 	QLineEdit *mediaMaxPort;
+	#ifdef SRTP
+	QButtonGroup* srtp;
+	QLineEdit* masterKey;
+	#endif
 };
 
 #endif // KSIPPREFERENCES_H_INCLUDED
