@@ -1,13 +1,68 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+    <message>
+        <source>Next Interface</source>
+        <translation>Nächste Schnittstelle</translation>
+    </message>
+    <message>
+        <source>Use</source>
+        <translation>Benutze</translation>
+    </message>
+    <message>
+        <source>KPhone found more than one interface.</source>
+        <translation>KPhone hat mehr als eine Schnittstelle gefunden.</translation>
+    </message>
+    <message>
+        <source>Do you want to use the default interface:</source>
+        <translation>Möchten Sie die Standard-Schnittstelle benutzen?</translation>
+    </message>
+    <message>
+        <source>Do you want to use</source>
+        <translation>Verfügbare Schnittstelle:</translation>
+    </message>
+    <message>
+        <source>Permanently rejected contacts</source>
+        <translation>Dauerhaft abgelehnte Kontakte</translation>
+    </message>
+    <message>
+        <source>Call Register</source>
+        <translation>Anrufverzeichnis</translation>
+    </message>
+    <message>
+        <source>Received calls</source>
+        <translation>Angenommene Anrufe</translation>
+    </message>
+    <message>
+        <source>Missed calls</source>
+        <translation>Verpasste Anrufe</translation>
+    </message>
+    <message>
+        <source>PhoneBook</source>
+        <translation>Telefonbuch</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation>Ja</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>Nein</translation>
+    </message>
+</context>
 <context>
     <name>AudioControl</name>
     <message>
         <source>Audio Properties</source>
-        <translation>Audio Eigenschaften</translation>
+        <translation>Audio-Eigenschaften</translation>
     </message>
     <message>
         <source>OSS Device Mode</source>
-        <translation>OSS Gerätemodus</translation>
+        <translation>OSS-Gerätemodus</translation>
     </message>
     <message>
         <source>ReadWrite</source>
@@ -19,11 +74,11 @@
     </message>
     <message>
         <source>Device for WriteOnly or ReadWrite:</source>
-        <translation>Gerät für Nur Schreiben oder Lesen/Schreiben:</translation>
+        <translation>Gerät für Nur-Schreib- oder Lese/Schreib-Zugriff:</translation>
     </message>
     <message>
         <source>Device for ReadOnly:</source>
-        <translation>Gerät für nur Lesen:</translation>
+        <translation>Gerät für Nur-Lese-Zugriff:</translation>
     </message>
     <message>
         <source>Preferred Codec</source>
@@ -43,7 +98,7 @@
     </message>
     <message>
         <source>Size of Payload</source>
-        <translation>Payload-Größe</translation>
+        <translation>Größe der Dateneinheiten</translation>
     </message>
     <message>
         <source>80 (10 ms Sample)</source>
@@ -67,7 +122,7 @@
     </message>
     <message>
         <source>ok button</source>
-        <translation>OK Button</translation>
+        <translation>OK-Knopf</translation>
     </message>
     <message>
         <source>OK</source>
@@ -75,11 +130,11 @@
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Button</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -94,19 +149,19 @@
     </message>
     <message>
         <source>CallAudio: Sending to remote site %s:%d</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: Sende an die Gegenstelle %s:%d</translation>
     </message>
     <message>
         <source>CallAudio: OSS device already open (readwrite)</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: Das OSS-Gerät ist bereits geöffnet (Lesen/Schreiben)</translation>
     </message>
     <message>
         <source>** audioIn: openDevice Failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>** audioIn: openDevice fehlgeschlagen.</translation>
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Input</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: Öffne OSS-Gerät %s zum Lesen</translation>
     </message>
     <message>
         <source>CallAudio: Creating OSS-&gt;RTP Diverter</source>
@@ -118,26 +173,26 @@
     </message>
     <message>
         <source>CallAudio: listening for incomming RTP</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: warte auf eingehende RTP-Verbindungen</translation>
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Input and Output</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: Öffne OSS-Gerät %s zum Schreiben und Lesen</translation>
     </message>
     <message>
         <source>** audioOut: openDevice Failed.</source>
-        <translation type="unfinished"></translation>
+        <translation>** audioOut: openDevice fehlgeschlagen.</translation>
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Output</source>
-        <translation type="unfinished"></translation>
+        <translation>CallAudio: Öffne OSS-Gerät %s zum Schreiben</translation>
     </message>
 </context>
 <context>
     <name>ContactParser</name>
     <message>
         <source>description</source>
-        <translation type="unfinished"></translation>
+        <translation>Beschreibung</translation>
     </message>
     <message>
         <source>uri</source>
@@ -167,7 +222,7 @@
     </message>
     <message>
         <source>DspAudioIn: UDP-failure(%d)</source>
-        <translation type="unfinished"></translation>
+        <translation>DspAudioIn: UDP-Fehler (%d)</translation>
     </message>
 </context>
 <context>
@@ -181,7 +236,7 @@
     <name>DspOutOss</name>
     <message>
         <source>Device Already Open</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerät ist bereits geöffnet</translation>
     </message>
     <message>
         <source>Open Failed</source>
@@ -189,11 +244,11 @@
     </message>
     <message>
         <source>Format not supported</source>
-        <translation type="unfinished"></translation>
+        <translation>Das Format wird nicht unterstützt</translation>
     </message>
     <message>
         <source>Unsupported Number of Channels</source>
-        <translation type="unfinished"></translation>
+        <translation>Nicht-unterstützte Anzahl an Kanälen</translation>
     </message>
     <message>
         <source>WARNING: nonmonophonic driver, forced into stereo mode (experimental)</source>
@@ -205,7 +260,7 @@
     </message>
     <message>
         <source>Device Not Open</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerät ist nicht geöffnet</translation>
     </message>
     <message>
         <source>warning: asked microphone for %d got %d</source>
@@ -224,7 +279,7 @@
     </message>
     <message>
         <source>SipClient: Receiving message...</source>
-        <translation type="unfinished"></translation>
+        <translation>SipClient: Empfange Nachricht ...</translation>
     </message>
     <message>
         <source>SipClient: STUN response for RTP</source>
@@ -255,11 +310,11 @@
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Knopf</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -389,15 +444,15 @@ könnten und versuchen Sie es erneut.</translation>
     </message>
     <message>
         <source>Attached [holding]</source>
-        <translation type="unfinished"></translation>
+        <translation>verbunden [gehalten]</translation>
     </message>
     <message>
         <source>Attached [active]</source>
-        <translation type="unfinished"></translation>
+        <translation>verbunden [aktiv]</translation>
     </message>
     <message>
         <source>Unattached</source>
-        <translation type="unfinished"></translation>
+        <translation>nicht verbunden</translation>
     </message>
     <message>
         <source>ERROR: %s
@@ -475,19 +530,19 @@ Nachricht gesendet an</translation>
     <name>KPhone</name>
     <message>
         <source>New Call...</source>
-        <translation>Neuer Anruf...</translation>
+        <translation>&amp;Neuer Anruf...</translation>
     </message>
     <message>
         <source>New Video Call...</source>
-        <translation>Neuer Videoanruf...</translation>
+        <translation>Neuer &amp;Videoanruf...</translation>
     </message>
     <message>
         <source>Identity...</source>
-        <translation>Identität...</translation>
+        <translation>&amp;Identität...</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
-        <translation>&amp;Quit</translation>
+        <translation>Beenden</translation>
     </message>
     <message>
         <source>&amp;File</source>
@@ -495,23 +550,23 @@ Nachricht gesendet an</translation>
     </message>
     <message>
         <source>SIP Preferences...</source>
-        <translation>SIP Eigenschaften...</translation>
+        <translation>SIP-Eigenschaften...</translation>
     </message>
     <message>
         <source>Audio Preferences...</source>
-        <translation>Audio Eigenschaften...</translation>
+        <translation>Audio-Eigenschaften...</translation>
     </message>
     <message>
         <source>Video Preferences...</source>
-        <translation>Video Eigenschaften...</translation>
+        <translation>Video-Eigenschaften...</translation>
     </message>
     <message>
         <source>Phone Book</source>
-        <translation>Telefonbuch</translation>
+        <translation>Telefonbuch...</translation>
     </message>
     <message>
         <source>Tray Icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Tray-Symbol</translation>
     </message>
     <message>
         <source>&amp;Preferences</source>
@@ -581,7 +636,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>is a &apos;Voice Over Internet&apos; phone</source>
-        <translation type="unfinished"></translation>
+        <translation>ist ein Software-Telefon für die &apos;Internet-Telefonie&apos;</translation>
     </message>
     <message>
         <source>Copyright (c) 2000 Billy Biggs</source>
@@ -597,7 +652,19 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>For more information, see</source>
-        <translation type="unfinished"></translation>
+        <translation>Weitere Informationen erhalten Sie unter</translation>
+    </message>
+    <message>
+        <source>&amp;Hide</source>
+        <translation>Verstecken</translation>
+    </message>
+    <message>
+        <source>S&amp;how</source>
+        <translation>Anzeigen</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -688,7 +755,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>busy</source>
-        <translation type="unfinished"></translation>
+        <translation>beschäftigt</translation>
     </message>
     <message>
         <source>berightback</source>
@@ -696,7 +763,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>away</source>
-        <translation type="unfinished"></translation>
+        <translation>abwesend</translation>
     </message>
     <message>
         <source>onthephone</source>
@@ -727,7 +794,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>ok button</source>
-        <translation>OK Knopf</translation>
+        <translation>OK-Knopf</translation>
     </message>
     <message>
         <source>OK</source>
@@ -735,11 +802,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Knopf</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -754,11 +821,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>User Part of SIP URL:</source>
-        <translation>Benutzer-Teil der SIP URL:</translation>
+        <translation>Benutzer-Teil der SIP-URL:</translation>
     </message>
     <message>
         <source>Host Part of SIP URL:</source>
-        <translation>Host-Teil der SIP URL:</translation>
+        <translation>Host-Teil der SIP-URL:</translation>
     </message>
     <message>
         <source>Outbound Proxy (optional):</source>
@@ -786,7 +853,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>help button</source>
-        <translation>Hilfe Knopf</translation>
+        <translation>Hilfe-Knopf</translation>
     </message>
     <message>
         <source>&amp;help...</source>
@@ -794,7 +861,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>ok button</source>
-        <translation>OK Knopf</translation>
+        <translation>OK-Knopf</translation>
     </message>
     <message>
         <source>OK</source>
@@ -802,11 +869,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Knopf</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
     <message>
         <source>Registration : not registered</source>
@@ -983,11 +1050,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Digest Authentication Request</source>
-        <translation>Digest Authentifizierungsanfrage</translation>
+        <translation>Digest-Authentifizierungsanfrage</translation>
     </message>
     <message>
         <source>Basic Authentication Request</source>
-        <translation>Basic Authentifizierungsanfrage</translation>
+        <translation>Einfache (basic) Authentifizierungsanfrage</translation>
     </message>
     <message>
         <source>Proxy Digest Authentication Request</source>
@@ -1026,7 +1093,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Text files (*.txt)</source>
-        <translation>Testdateien (*.txt)</translation>
+        <translation>Textdateien (*.txt)</translation>
     </message>
     <message>
         <source>open file dialogChoose a file</source>
@@ -1065,7 +1132,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Select first item.</source>
-        <translation>Erstes Objektv wählen.</translation>
+        <translation>Erstes Objekt wählen.</translation>
     </message>
     <message>
         <source>Are You Sure ?</source>
@@ -1100,7 +1167,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>ok button</source>
-        <translation>OK Knopf</translation>
+        <translation>OK-Knopf</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1108,11 +1175,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Knopf</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -1135,7 +1202,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -1150,7 +1217,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 <context>
@@ -1169,15 +1236,15 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Permanently rejected contacts</source>
-        <translation>Kontakte permanent ablehnen</translation>
+        <translation>Dauerhaft abgelehnte Kontakte</translation>
     </message>
     <message>
         <source>Call Register</source>
-        <translation type="unfinished"></translation>
+        <translation>Anrufverzeichnis</translation>
     </message>
     <message>
         <source>Received calls</source>
-        <translation>Empfangene Anrufe</translation>
+        <translation>Angenommene Anrufe</translation>
     </message>
     <message>
         <source>Missed calls</source>
@@ -1208,31 +1275,35 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Connected: </source>
-        <translation></translation>
+        <translation>Verbunden: </translation>
     </message>
     <message>
         <source>Redirected: </source>
-        <translation></translation>
+        <translation>Umgeleitet: </translation>
     </message>
     <message>
         <source>Call Failed: </source>
-        <translation></translation>
+        <translation>Anruf fehlgeschlagen: </translation>
     </message>
     <message>
         <source>Disconnecting</source>
-        <translation></translation>
+        <translation>Abbauen</translation>
     </message>
     <message>
         <source>Transfering</source>
-        <translation></translation>
+        <translation>Transferieren</translation>
     </message>
     <message>
         <source>Querying options</source>
-        <translation></translation>
+        <translation>Anfrage-Optionen</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation></translation>
+        <translation>Verbunden</translation>
+    </message>
+    <message>
+        <source>Call Failed</source>
+        <translation>Anruf fehlgeschlagen</translation>
     </message>
     <message>
         <source>Not Acceptable Here</source>
@@ -1240,7 +1311,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Rejecting call invitation</source>
-        <translation></translation>
+        <translation>Anruf wird abgelehnt</translation>
     </message>
     <message>
         <source>Invitation received</source>
@@ -1248,11 +1319,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Session update requested</source>
-        <translation></translation>
+        <translation>Sitzungsaktualisierung angefordert</translation>
     </message>
     <message>
         <source>Remote end disconnected</source>
-        <translation></translation>
+        <translation>Gegenstelle getrennt</translation>
     </message>
     <message>
         <source>Refer</source>
@@ -1260,7 +1331,35 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>Request cancelled</source>
-        <translation></translation>
+        <translation>Anfrage abgebrochen</translation>
+    </message>
+    <message>
+        <source>No Response</source>
+        <translation>Keine Antwort</translation>
+    </message>
+    <message>
+        <source>Trying</source>
+        <translation>Anrufversuch</translation>
+    </message>
+    <message>
+        <source>Ringing</source>
+        <translation>Rufen</translation>
+    </message>
+    <message>
+        <source>Call is Being Forwarded</source>
+        <translation>Anruf wird weitergeleitet</translation>
+    </message>
+    <message>
+        <source>Queued</source>
+        <translation>In Warteschlange</translation>
+    </message>
+    <message>
+        <source>Forbidden</source>
+        <translation>Nicht erlaubt</translation>
+    </message>
+    <message>
+        <source>Not Found</source>
+        <translation>Nicht gefunden</translation>
     </message>
 </context>
 <context>
@@ -1310,7 +1409,7 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>ok button</source>
-        <translation>OK Knopf</translation>
+        <translation>OK-Knopf</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1318,11 +1417,11 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Abbruch Knopf</translation>
+        <translation>Abbrechen-Knopf</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Abbruch</translation>
+        <translation>Abbrechen</translation>
     </message>
 </context>
 </TS>
