@@ -3,11 +3,11 @@
     <name>AudioControl</name>
     <message>
         <source>Audio Properties</source>
-        <translation>Proprits Audio</translation>
+        <translation>Propriétés Audio</translation>
     </message>
     <message>
         <source>OSS Device Mode</source>
-        <translation>Mode du priphrique OSS</translation>
+        <translation>Mode du périphérique OSS</translation>
     </message>
     <message>
         <source>ReadWrite</source>
@@ -19,15 +19,15 @@
     </message>
     <message>
         <source>Device for WriteOnly or ReadWrite:</source>
-        <translation>Priphrique en EcritureSeule ou EcritureLecture:</translation>
+        <translation>Périphérique en EcritureSeule ou EcritureLecture:</translation>
     </message>
     <message>
         <source>Device for ReadOnly:</source>
-        <translation>Priphrique en LectureSeule:</translation>
+        <translation>Périphérique en LectureSeule:</translation>
     </message>
     <message>
         <source>Preferred Codec</source>
-        <translation>Codec Prfr </translation>
+        <translation>Codec Préféré </translation>
     </message>
     <message>
         <source>G711u</source>
@@ -46,16 +46,16 @@
         <translation>Taille de Payload</translation>
     </message>
     <message>
-        <source>80 (chantillon 10 ms)</source>
+        <source>80 (échantillon 10 ms)</source>
         <translation></translation>
     </message>
     <message>
-        <source>160 (chantillon 20 ms)</source>
+        <source>160 (échantillon 20 ms)</source>
         <translation></translation>
     </message>
     <message>
         <source>Ringing tone  (system bell)</source>
-        <translation>Sonnerie (systme)</translation>
+        <translation>Sonnerie (système)</translation>
     </message>
     <message>
         <source>Don&apos;t use ringing tone</source>
@@ -86,7 +86,7 @@
     <name>CallAudio</name>
     <message>
         <source>CallAudio: SendToRemote called but we don&apos;t have a valid session description yet</source>
-        <translation>CallAudio: SendToRemote appele mais actuellement aucun descripteur de session valide</translation>
+        <translation>CallAudio: SendToRemote appelée mais actuellement aucun descripteur de session valide</translation>
     </message>
     <message>
         <source>CallAudio: Remote is currently putting us on hold, waiting patiently</source>
@@ -98,7 +98,7 @@
     </message>
     <message>
         <source>CallAudio: OSS device already open (readwrite)</source>
-        <translation>CallAudio: Priphrique OSS dj ouvert (LectureEcriture)</translation>
+        <translation>CallAudio: Périphérique OSS déjà ouvert (LectureEcriture)</translation>
     </message>
     <message>
         <source>** audioIn: openDevice Failed.</source>
@@ -106,15 +106,15 @@
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Input</source>
-        <translation>CallAudio: Ouverture du priphrique OSS %s en entre</translation>
+        <translation>CallAudio: Ouverture du périphérique OSS %s en entrée</translation>
     </message>
     <message>
         <source>CallAudio: Creating OSS-&gt;RTP Diverter</source>
-        <translation>CallAudio: Cration d'un OSS-&gt;RTP Diverter</translation>
+        <translation>CallAudio: Création d'un OSS-&gt;RTP Diverter</translation>
     </message>
     <message>
         <source>CallAudio: Opening SW for video input and output</source>
-        <translation>CallAudio: Ouverture de SW pour entre/sortie vido</translation>
+        <translation>CallAudio: Ouverture de SW pour entrée/sortie vidéo</translation>
     </message>
     <message>
         <source>CallAudio: listening for incomming RTP</source>
@@ -122,7 +122,7 @@
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Input and Output</source>
-        <translation>CallAudio: Ouverture priphrique OSS %s en entre/sortie</translation>
+        <translation>CallAudio: Ouverture périphérique OSS %s en entrée/sortie</translation>
     </message>
     <message>
         <source>** audioOut: openDevice Failed.</source>
@@ -130,7 +130,7 @@
     </message>
     <message>
         <source>CallAudio: Opening OSS device %s for Output</source>
-        <translation>CallAudio: Ouverture priphrique OSS %s en sortie</translation>
+        <translation>CallAudio: Ouverture périphérique OSS %s en sortie</translation>
     </message>
 </context>
 <context>
@@ -181,7 +181,7 @@
     <name>DspOutOss</name>
     <message>
         <source>Device Already Open</source>
-        <translation>Priphrique dj ouvert</translation>
+        <translation>Périphérique déjà ouvert</translation>
     </message>
     <message>
         <source>Open Failed</source>
@@ -189,15 +189,15 @@
     </message>
     <message>
         <source>Format not supported</source>
-        <translation>Format non support </translation>
+        <translation>Format non supporté </translation>
     </message>
     <message>
         <source>Unsupported Number of Channels</source>
-        <translation>Nombre de canals non support </translation>
+        <translation>Nombre de canals non supporté </translation>
     </message>
     <message>
         <source>WARNING: nonmonophonic driver, forced into stereo mode (experimental)</source>
-        <translation>ATTENTION: pilote mono, force le mode stro (exprimental)</translation>
+        <translation>ATTENTION: pilote mono, force le mode stéréo (expérimental)</translation>
     </message>
     <message>
         <source>WARNING: driver rounded %d Hz request to %d Hz, off by %f%%</source>
@@ -205,37 +205,37 @@
     </message>
     <message>
         <source>Device Not Open</source>
-        <translation>Priphrique Non Ouvert</translation>
+        <translation>Périphérique Non Ouvert</translation>
     </message>
     <message>
         <source>warning: asked microphone for %d got %d</source>
-        <translation>attention: %d demand au micro, %d obtenu</translation>
+        <translation>attention: %d demandé au micro, %d obtenu</translation>
     </message>
 </context>
 <context>
     <name>DspOutRtp</name>
     <message>
         <source>DspOutRtp:: Can&apos;t create socket</source>
-        <translation>DspOutRtp:: cration socket impossible</translation>
+        <translation>DspOutRtp:: création socket impossible</translation>
     </message>
     <message>
         <source>DspOutRtp::Hostname lookup failed</source>
-        <translation>DspOutRtp:: chec recherche du nom</translation>
+        <translation>DspOutRtp:: échec recherche du nom</translation>
     </message>
     <message>
         <source>SipClient: Receiving message...</source>
-        <translation>SipClient: rception message...</translation>
+        <translation>SipClient: réception message...</translation>
     </message>
     <message>
         <source>SipClient: STUN response for RTP</source>
-        <translation>SipClient: rponse STUN pour RTP</translation>
+        <translation>SipClient: réponse STUN pour RTP</translation>
     </message>
 </context>
 <context>
     <name>KCallTransfer</name>
     <message>
         <source>Transfer to URI:</source>
-        <translation>Transfr vers l'URI:</translation>
+        <translation>Transféré vers l'URI:</translation>
     </message>
     <message>
         <source>help button</source>
@@ -306,7 +306,7 @@
     </message>
     <message>
         <source>KCallWidget: Switching calls...</source>
-        <translation>KCallWidget: change des appels...</translation>
+        <translation>KCallWidget: échange des appels...</translation>
     </message>
     <message>
         <source>Call: </source>
@@ -314,7 +314,7 @@
     </message>
     <message>
         <source>Incoming Video Call: </source>
-        <translation>Appel Vido Entrant: </translation>
+        <translation>Appel Vidéo Entrant: </translation>
     </message>
     <message>
         <source>Incoming Call: </source>
@@ -322,7 +322,7 @@
     </message>
     <message>
         <source>Accept</source>
-        <translation>Rpondre</translation>
+        <translation>Répondre</translation>
     </message>
     <message>
         <source>Reject</source>
@@ -330,7 +330,7 @@
     </message>
     <message>
         <source>Outgoing Video Call: </source>
-        <translation>Appel Vido Sortant: </translation>
+        <translation>Appel Vidéo Sortant: </translation>
     </message>
     <message>
         <source>Outgoing Call: </source>
@@ -348,11 +348,11 @@
         <source>Close any program which might be using soundcard 
 and then retry dial.</source>
         <translation>Fermez tous les programmes susceptibles d'utiliser la carte son
-et ressayez d'appeler.</translation>
+et réessayez d'appeler.</translation>
     </message>
     <message>
         <source>KCallAudio: Broken output pipe, disconnecting unpolitely</source>
-        <translation>KCallAudio: Broken output pipe, dconnection intempestive</translation>
+        <translation>KCallAudio: Broken output pipe, déconnection intempestive</translation>
     </message>
     <message>
         <source>Unhold</source>
@@ -368,7 +368,7 @@ et ressayez d'appeler.</translation>
     </message>
     <message>
         <source>Call redirected to: </source>
-        <translation>Appel redirig vers: </translation>
+        <translation>Appel redirigé vers: </translation>
     </message>
     <message>
         <source>Do you want to proceed ? </source>
@@ -376,19 +376,19 @@ et ressayez d'appeler.</translation>
     </message>
     <message>
         <source>KCallWidget: Starting force disconnect...</source>
-        <translation>KCallWidget: Force la dconnexion...</translation>
+        <translation>KCallWidget: Force la déconnexion...</translation>
     </message>
     <message>
         <source>Attached [holding]</source>
-        <translation>Raccord [en attente]</translation>
+        <translation>Raccordé [en attente]</translation>
     </message>
     <message>
         <source>Attached [active]</source>
-        <translation>Raccord [actif]</translation>
+        <translation>Raccordé [actif]</translation>
     </message>
     <message>
         <source>Unattached</source>
-        <translation>Non raccord </translation>
+        <translation>Non raccordé </translation>
     </message>
     <message>
         <source>Accept Call</source>
@@ -398,11 +398,11 @@ et ressayez d'appeler.</translation>
         <source>Close any program which might be using soundcard 
 and then retry accepting call.</source>
         <translation>Fermer tous les programmes susceptibles d'utiliser la carte son
-puis ressayez de rpondre.</translation>
+puis réessayez de répondre.</translation>
     </message>
     <message>
         <source>Accepted codec not found.</source>
-        <translation>Codec pour la rception non trouv.</translation>
+        <translation>Codec pour la réception non trouvé.</translation>
     </message>
 </context>
 <context>
@@ -449,7 +449,7 @@ puis ressayez de rpondre.</translation>
     </message>
     <message>
         <source>Message sent to </source>
-        <translation>Message envoy  </translation>
+        <translation>Message envoyé à </translation>
     </message>
 </context>
 <context>
@@ -460,11 +460,11 @@ puis ressayez de rpondre.</translation>
     </message>
     <message>
         <source>New Video Call...</source>
-        <translation>Nouvel appel vido...</translation>
+        <translation>Nouvel appel vidéo...</translation>
     </message>
     <message>
         <source>Identity...</source>
-        <translation>Identit...</translation>
+        <translation>Identité...</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
@@ -476,15 +476,15 @@ puis ressayez de rpondre.</translation>
     </message>
     <message>
         <source>SIP Preferences...</source>
-        <translation>Prfrences SIP...</translation>
+        <translation>Préférences SIP...</translation>
     </message>
     <message>
         <source>Audio Preferences...</source>
-        <translation>Prfrences Audios...</translation>
+        <translation>Préférences Audios...</translation>
     </message>
     <message>
         <source>Video Preferences...</source>
-        <translation>Prfrences Vidos...</translation>
+        <translation>Préférences Vidéos...</translation>
     </message>
     <message>
         <source>Phone Book</source>
@@ -496,7 +496,7 @@ puis ressayez de rpondre.</translation>
     </message>
     <message>
         <source>&amp;Preferences</source>
-        <translation>&amp;Prfrences</translation>
+        <translation>&amp;Préférences</translation>
     </message>
     <message>
         <source>Help</source>
@@ -504,7 +504,7 @@ puis ressayez de rpondre.</translation>
     </message>
     <message>
         <source>About KPhone</source>
-        <translation> propos de KPhone</translation>
+        <translation>À propos de KPhone</translation>
     </message>
     <message>
         <source>&amp;Help</source>
@@ -534,26 +534,26 @@ description. If you want your contacts to be displayed in the main UI, just chec
 contacts you can return to the main UI by clicking Hide. All your selected contacts should now appear there. Making calls and 
 sending instant messages to your contacts is easy with the RMB. Just click and select the function which you&apos;d like to initiate.
 </source>
-        <translation>Lorsque vous dmarrez KPhone pour la premire fois, vous devez utiliser la fentre qui apparat pour indiquer votre identit.
-Les informations ncessaires  l'utilisation du protocole SIP sont : &apos;Nom&apos;, &apos;Partie utilisateur de l'RL SIP&apos; et &apos;Partie hote de l'URL SIP&apos;.
-Note pour les utilisateurs de KPhone 3.xx : copier le fichier &apos;~/.kde/share/config/kphonerc&apos; vers le rpertoire &apos;~/.qt&apos;.
+        <translation>Lorsque vous démarrez KPhone pour la première fois, vous devez utiliser la fenêtre qui apparaît pour indiquer votre identité.
+Les informations nécessaires à l'utilisation du protocole SIP sont : &apos;Nom&apos;, &apos;Partie utilisateur de l'RL SIP&apos; et &apos;Partie hote de l'URL SIP&apos;.
+Note pour les utilisateurs de KPhone 3.xx : copier le fichier &apos;~/.kde/share/config/kphonerc&apos; vers le répertoire &apos;~/.qt&apos;.
 
-Si vous utilisez un serveur DNS NAPTR/SRV, vous pouvez laisser les champs &apos;Proxy Sortant&apos; et &apos;Authentification Utilisateur&apos; vides, car KPhone va automatiquement chercher l'information serveur grce  la &apos;Partie hte de l'URL SIP&apos; et demander le nom utilisateur/mot de passe.
+Si vous utilisez un serveur DNS NAPTR/SRV, vous pouvez laisser les champs &apos;Proxy Sortant&apos; et &apos;Authentification Utilisateur&apos; vides, car KPhone va automatiquement chercher l'information serveur grâce à la &apos;Partie hôte de l'URL SIP&apos; et demander le nom utilisateur/mot de passe.
 
-Cocher la case &apos;Enregistrement auto&apos; si vous voulez que KPhone vous enregistre automatiquement lorsque l'application dmarre.
-Si vous voulez utiliser plusieurs identits, dmarrez KPhone avec l'option &apos;-u&apos; en spcifiant le nom d'utilisateur dsir.
+Cocher la case &apos;Enregistrement auto&apos; si vous voulez que KPhone vous enregistre automatiquement lorsque l'application démarre.
+Si vous voulez utiliser plusieurs identités, démarrez KPhone avec l'option &apos;-u&apos; en spécifiant le nom d'utilisateur désiré.
 Par exemple:  &apos;kphone -u johnybigoude&apos;.
 
-Si vous tes sur un rseau NAT (translation d'adresse), vous devez slectionner l'option &apos;Utiliser un serveur STUN&apos; dans Prfrences -&gt; Prfrences SIP -&gt; Socket.
+Si vous êtes sur un réseau NATé (translation d'adresse), vous devez sélectionner l'option &apos;Utiliser un serveur STUN&apos; dans Préférences -&gt; Préférences SIP -&gt; Socket.
 
-Lors de l'utilisation de la fentre principale, le bouton droit de la souris vous permet d'accder directement  un menu contenant toutes les fonctionnalits importantes de KPhone. Vous pouvez aussi utiliser l'annuaire pour stocker vos contacts. Cela n'est bien sr pas obligatoire mais vous rendra plus efficace avec KPhone.
+Lors de l'utilisation de la fenêtre principale, le bouton droit de la souris vous permet d'accéder directement à un menu contenant toutes les fonctionnalités importantes de KPhone. Vous pouvez aussi utiliser l'annuaire pour stocker vos contacts. Cela n'est bien sûr pas obligatoire mais vous rendra plus efficace avec KPhone.
 
-Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer le nom de la personne, son identit SIP et sa description (optionnel). Si vous voulez que vos contacts apparaissent dans la fentre principale, cocher la bote &apos;Ajouter Identit...&apos;. Lorsque l'dition de vos contacts est termine, vous pouvez retourner  la fentre principale en cliquant &apos;Cacher&apos; : tous les contacts slectionns devraient alors apparatre. Il est ensuite facile d'envoyer des messages instantans ou d'appeler les contacts en utilisant le bouton droit de la souris : cliquez puis slectionnez la fonction que vous voulez utiliser.
+Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer le nom de la personne, son identité SIP et sa description (optionnel). Si vous voulez que vos contacts apparaissent dans la fenêtre principale, cocher la boîte &apos;Ajouter Identité...&apos;. Lorsque l'édition de vos contacts est terminée, vous pouvez retourner à la fenêtre principale en cliquant &apos;Cacher&apos; : tous les contacts sélectionnés devraient alors apparaître. Il est ensuite facile d'envoyer des messages instantanés ou d'appeler les contacts en utilisant le bouton droit de la souris : cliquez puis sélectionnez la fonction que vous voulez utiliser.
 </translation>
     </message>
     <message>
         <source>is a &apos;Voice Over Internet&apos; phone</source>
-        <translation>est un tlphone &apos;Voice Over Internet&apos;</translation>
+        <translation>est un téléphone &apos;Voice Over Internet&apos;</translation>
     </message>
     <message>
         <source>Copyright (c) 2000 Billy Biggs</source>
@@ -565,7 +565,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>KPhone is released under the GPL</source>
-        <translation>KPhone est distribu sous licence GPL</translation>
+        <translation>KPhone est distribué sous licence GPL</translation>
     </message>
     <message>
         <source>For more information, see</source>
@@ -576,7 +576,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>KPhoneView</name>
     <message>
         <source>Set Identity</source>
-        <translation>Entrer l'identit </translation>
+        <translation>Entrer l'identité </translation>
     </message>
     <message>
         <source>Send Message</source>
@@ -588,7 +588,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Video Call</source>
-        <translation>Appel Vido</translation>
+        <translation>Appel Vidéo</translation>
     </message>
     <message>
         <source>Phone Book</source>
@@ -600,11 +600,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Busy</source>
-        <translation>Occup </translation>
+        <translation>Occupé </translation>
     </message>
     <message>
         <source>Be Right Back</source>
-        <translation>De Retour Bientt</translation>
+        <translation>De Retour Bientôt</translation>
     </message>
     <message>
         <source>Away</source>
@@ -612,7 +612,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>On The Phone</source>
-        <translation>Au Tlphone</translation>
+        <translation>Au Téléphone</translation>
     </message>
     <message>
         <source>Out To Lunch</source>
@@ -620,7 +620,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>KPhoneView: Incoming Instant Message</source>
-        <translation>KPhoneView: Message Instantan Entrant</translation>
+        <translation>KPhoneView: Message Instantané Entrant</translation>
     </message>
     <message>
         <source>KPhone</source>
@@ -632,15 +632,15 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Do you want to accept and create a contact ?</source>
-        <translation>Voulez vous rpondre et crer un contact ?</translation>
+        <translation>Voulez vous répondre et créer un contact ?</translation>
     </message>
     <message>
         <source>Accept</source>
-        <translation>Rpondre</translation>
+        <translation>Répondre</translation>
     </message>
     <message>
         <source>Reject permanently</source>
-        <translation>Refus dfinitif</translation>
+        <translation>Refus définitif</translation>
     </message>
     <message>
         <source>Reject this time</source>
@@ -652,7 +652,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Set First Identity.</source>
-        <translation>Entrer la Premire Identit </translation>
+        <translation>Entrer la Première Identité </translation>
     </message>
     <message>
         <source>online</source>
@@ -660,11 +660,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>busy</source>
-        <translation>occup </translation>
+        <translation>occupé </translation>
     </message>
     <message>
         <source>berightback</source>
-        <translation>deretourbientt</translation>
+        <translation>deretourbientôt</translation>
     </message>
     <message>
         <source>away</source>
@@ -672,7 +672,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>onthephone</source>
-        <translation>autlphone</translation>
+        <translation>autéléphone</translation>
     </message>
     <message>
         <source>outtolunch</source>
@@ -718,7 +718,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>KSipIdentityEdit</name>
     <message>
         <source>Identity Editor</source>
-        <translation>Editeur d'identit </translation>
+        <translation>Editeur d'identité </translation>
     </message>
     <message>
         <source>Full Name:</source>
@@ -730,7 +730,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Host Part of SIP URL:</source>
-        <translation>Partie hte de l'URL SIP:</translation>
+        <translation>Partie hôte de l'URL SIP:</translation>
     </message>
     <message>
         <source>Outbound Proxy (optional):</source>
@@ -786,18 +786,18 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Unregister</source>
-        <translation>Se dsenregistrer</translation>
+        <translation>Se désenregistrer</translation>
     </message>
 </context>
 <context>
     <name>KSipOptions</name>
     <message>
         <source>URI to Request Options For:</source>
-        <translation>URI o demander les Options:</translation>
+        <translation>URI où demander les Options:</translation>
     </message>
     <message>
         <source>Results:</source>
-        <translation>Rsultats:</translation>
+        <translation>Résultats:</translation>
     </message>
     <message>
         <source>Make Query</source>
@@ -808,11 +808,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>KSipPreferences</name>
     <message>
         <source>Global SIP Preferences</source>
-        <translation>Prfrences SIP Globales</translation>
+        <translation>Préférences SIP Globales</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation>Rglages</translation>
+        <translation>Réglages</translation>
     </message>
     <message>
         <source>Hide Via</source>
@@ -848,7 +848,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Socket Protocol (Kphone restart needed to apply change)</source>
-        <translation>Utiliser les Sockets (redmarrer KPhone pour prendre en compte cette modification)</translation>
+        <translation>Utiliser les Sockets (redémarrer KPhone pour prendre en compte cette modification)</translation>
     </message>
     <message>
         <source>UDP</source>
@@ -872,11 +872,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Symmetric Signalling</source>
-        <translation type="unfinished">Signal Symtrique</translation>
+        <translation type="unfinished">Signal Symétrique</translation>
     </message>
     <message>
         <source>Symmetric Media</source>
-        <translation type="unfinished">Mdia Symtrique</translation>
+        <translation type="unfinished">Média Symétrique</translation>
     </message>
     <message>
         <source>STUN Server (address:port):</source>
@@ -884,23 +884,23 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Request Period for STUN Server (second):</source>
-        <translation>Priode pour serveur STUN (secondes):</translation>
+        <translation>Période pour serveur STUN (secondes):</translation>
     </message>
     <message>
         <source>Media Min Port:</source>
-        <translation>Port min. pour Mdia:</translation>
+        <translation>Port min. pour Média:</translation>
     </message>
     <message>
         <source>Media Max Port:</source>
-        <translation>Port max. pour Mdia:</translation>
+        <translation>Port max. pour Média:</translation>
     </message>
     <message>
         <source>Call Preferences</source>
-        <translation>Prfrences Appel</translation>
+        <translation>Préférences Appel</translation>
     </message>
     <message>
         <source>Busy Message:</source>
-        <translation>Message Occup:</translation>
+        <translation>Message Occupé:</translation>
     </message>
     <message>
         <source>Call Forwarding</source>
@@ -927,15 +927,15 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>KSipRegistrations</name>
     <message>
         <source>off</source>
-        <translation>dconnect </translation>
+        <translation>déconnecté </translation>
     </message>
     <message>
         <source>Identity</source>
-        <translation>Identit </translation>
+        <translation>Identité </translation>
     </message>
     <message>
         <source>Restart Kphone to apply identity changes.</source>
-        <translation>Redmarrer KPhone pour appliquer les changements d'identit.</translation>
+        <translation>Redémarrer KPhone pour appliquer les changements d'identité.</translation>
     </message>
     <message>
         <source>Inactive</source>
@@ -947,7 +947,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Auth Required...</source>
-        <translation>Auth. Demande...</translation>
+        <translation>Auth. Demandée...</translation>
     </message>
     <message>
         <source>Active</source>
@@ -955,27 +955,27 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Unregistering...</source>
-        <translation>Dsenregistrement...</translation>
+        <translation>Désenregistrement...</translation>
     </message>
     <message>
         <source>Reregistering...</source>
-        <translation>R-enregistrement...</translation>
+        <translation>Ré-enregistrement...</translation>
     </message>
     <message>
         <source>Digest Authentication Request</source>
-        <translation>Auth. Digest demande</translation>
+        <translation>Auth. Digest demandée</translation>
     </message>
     <message>
         <source>Basic Authentication Request</source>
-        <translation>Basic Auth. demande</translation>
+        <translation>Basic Auth. demandée</translation>
     </message>
     <message>
         <source>Proxy Digest Authentication Request</source>
-        <translation>Proxy Auth. Digest demande</translation>
+        <translation>Proxy Auth. Digest demandée</translation>
     </message>
     <message>
         <source>Proxy Basic Authentication Request</source>
-        <translation>Proxy Basic Auth. demande</translation>
+        <translation>Proxy Basic Auth. demandée</translation>
     </message>
 </context>
 <context>
@@ -1033,7 +1033,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Permanently rejected contacts</source>
-        <translation>Contacts dfinitivement rejets</translation>
+        <translation>Contacts définitivement rejetés</translation>
     </message>
     <message>
         <source>PhoneBook</source>
@@ -1049,7 +1049,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Are You Sure ?</source>
-        <translation>Etes vous sr(e) ?</translation>
+        <translation>Etes vous sûr(e) ?</translation>
     </message>
     <message>
         <source>Yes</source>
@@ -1068,7 +1068,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Identity:</source>
-        <translation>Identit:</translation>
+        <translation>Identité:</translation>
     </message>
     <message>
         <source>Description:</source>
@@ -1076,7 +1076,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Add Identity to Contacts List</source>
-        <translation>Ajouter  la liste de contacts</translation>
+        <translation>Ajouter à la liste de contacts</translation>
     </message>
     <message>
         <source>ok button</source>
@@ -1099,7 +1099,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>PhoneBookEditIdentity</name>
     <message>
         <source>Identity:</source>
-        <translation>Identit:</translation>
+        <translation>Identité:</translation>
     </message>
     <message>
         <source>Description:</source>
@@ -1107,7 +1107,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Add Identity to Contacts List</source>
-        <translation>Ajouter  la liste des contacts</translation>
+        <translation>Ajouter à la liste des contacts</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1137,7 +1137,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>PhoneBookParser</name>
     <message>
         <source>Identity</source>
-        <translation>Identit </translation>
+        <translation>Identité </translation>
     </message>
     <message>
         <source>Contact</source>
@@ -1149,7 +1149,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Permanently rejected contacts</source>
-        <translation>Contacts dfinitivements rejets</translation>
+        <translation>Contacts définitivements rejetés</translation>
     </message>
     <message>
         <source>Call Register</source>
@@ -1157,11 +1157,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Received calls</source>
-        <translation>Appels reus</translation>
+        <translation>Appels reçus</translation>
     </message>
     <message>
         <source>Missed calls</source>
-        <translation>Appels manqus</translation>
+        <translation>Appels manqués</translation>
     </message>
     <message>
         <source>PhoneBook</source>
@@ -1184,15 +1184,15 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>SipCallMember</name>
     <message>
         <source>Response: </source>
-        <translation>Rponse: </translation>
+        <translation>Réponse: </translation>
     </message>
     <message>
         <source>Connected: </source>
-        <translation>Connect: </translation>
+        <translation>Connecté: </translation>
     </message>
     <message>
         <source>Redirected: </source>
-        <translation>Redirig: </translation>
+        <translation>Redirigé: </translation>
     </message>
     <message>
         <source>Call Failed: </source>
@@ -1200,7 +1200,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Disconnecting</source>
-        <translation>Dconnexion</translation>
+        <translation>Déconnexion</translation>
     </message>
     <message>
         <source>Transfering</source>
@@ -1212,11 +1212,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Connected</source>
-        <translation>Connect </translation>
+        <translation>Connecté </translation>
     </message>
     <message>
         <source>Not Acceptable Here</source>
-        <translation>Non accept ici</translation>
+        <translation>Non accepté ici</translation>
     </message>
     <message>
         <source>Rejecting call invitation</source>
@@ -1224,15 +1224,15 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Invitation received</source>
-        <translation>Invitation reue</translation>
+        <translation>Invitation reçue</translation>
     </message>
     <message>
         <source>Session update requested</source>
-        <translation>Demande de remise  jour de Session</translation>
+        <translation>Demande de remise à jour de Session</translation>
     </message>
     <message>
         <source>Remote end disconnected</source>
-        <translation>Correspondant deconnect </translation>
+        <translation>Correspondant deconnecté </translation>
     </message>
     <message>
         <source>Refer</source>
@@ -1240,7 +1240,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Request cancelled</source>
-        <translation>Demande annule</translation>
+        <translation>Demande annulée</translation>
     </message>
 </context>
 <context>
@@ -1251,11 +1251,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>Busy</source>
-        <translation>Occup </translation>
+        <translation>Occupé </translation>
     </message>
     <message>
         <source>Be Right Back</source>
-        <translation>Bientt de retour</translation>
+        <translation>Bientôt de retour</translation>
     </message>
     <message>
         <source>Away</source>
@@ -1263,7 +1263,7 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     </message>
     <message>
         <source>On The Phone</source>
-        <translation>Au Tlphone</translation>
+        <translation>Au Téléphone</translation>
     </message>
     <message>
         <source>Out To Lunch</source>
@@ -1274,11 +1274,11 @@ Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer
     <name>VideoControl</name>
     <message>
         <source>Video Properties</source>
-        <translation>Proprits Vidos</translation>
+        <translation>Propriétés Vidéos</translation>
     </message>
     <message>
         <source>Preferred Video Codec</source>
-        <translation>Codec Vido Prfr </translation>
+        <translation>Codec Vidéo Préféré </translation>
     </message>
     <message>
         <source>H261</source>
