@@ -59,7 +59,7 @@
     </message>
     <message>
         <source>Don&apos;t use ringing tone</source>
-        <translation>No usar tom de chamada</translation>
+        <translation>Não usar tom de chamada</translation>
     </message>
     <message>
         <source>Use ringing tone</source>
@@ -75,7 +75,7 @@
     </message>
     <message>
         <source>cancel button</source>
-        <translation>Cancelar boto</translation>
+        <translation>Cancelar botão</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -458,7 +458,7 @@ and then retry accepting call.</source>
     </message>
     <message>
         <source>New Video Call...</source>
-        <translation>Nova chamada de vdeo...</translation>
+        <translation>Nova chamada de vídeo...</translation>
     </message>
     <message>
         <source>Identity...</source>
@@ -474,19 +474,19 @@ and then retry accepting call.</source>
     </message>
     <message>
         <source>SIP Preferences...</source>
-        <translation>Preferncias do SIP...</translation>
+        <translation>Preferências do SIP...</translation>
     </message>
     <message>
         <source>Audio Preferences...</source>
-        <translation>Preferncias de Audio...</translation>
+        <translation>Preferências de Audio...</translation>
     </message>
     <message>
         <source>Video Preferences...</source>
-        <translation>Preferncias de Vdeo...</translation>
+        <translation>Preferências de Vídeo...</translation>
     </message>
     <message>
         <source>Phone Book</source>
-        <translation>Agenda Telefnica</translation>
+        <translation>Agenda Telefônica</translation>
     </message>
     <message>
         <source>Tray Icon</source>
@@ -494,7 +494,7 @@ and then retry accepting call.</source>
     </message>
     <message>
         <source>&amp;Preferences</source>
-        <translation>&amp;Preferncias</translation>
+        <translation>&amp;Preferências</translation>
     </message>
     <message>
         <source>Help</source>
@@ -674,7 +674,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>Username:</source>
-        <translation>Usurio:</translation>
+        <translation>Usuário:</translation>
     </message>
     <message>
         <source>Password:</source>
@@ -682,7 +682,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>ok button</source>
-        <translation>boto OK</translation>
+        <translation>botão OK</translation>
     </message>
     <message>
         <source>OK</source>
@@ -690,7 +690,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>cancel button</source>
-        <translation>boto cancelar</translation>
+        <translation>botão cancelar</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -709,7 +709,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>User Part of SIP URL:</source>
-        <translation>Parte de usurio da URL SIP:</translation>
+        <translation>Parte de usuário da URL SIP:</translation>
     </message>
     <message>
         <source>Host Part of SIP URL:</source>
@@ -729,7 +729,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>Auto Register</source>
-        <translation>Registro Automtico</translation>
+        <translation>Registro Automático</translation>
     </message>
     <message>
         <source>Register</source>
@@ -737,7 +737,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>help button</source>
-        <translation>boto ajuda</translation>
+        <translation>botão ajuda</translation>
     </message>
     <message>
         <source>&amp;help...</source>
@@ -745,7 +745,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>ok button</source>
-        <translation>boto OK</translation>
+        <translation>botão OK</translation>
     </message>
     <message>
         <source>OK</source>
@@ -753,7 +753,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>cancel button</source>
-        <translation>boto cancelar</translation>
+        <translation>botão cancelar</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -1020,7 +1020,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>PhoneBook</source>
-        <translation>Agenda Telefnica</translation>
+        <translation>Agenda Telefônica</translation>
     </message>
     <message>
         <source>KPhone</source>
@@ -1032,7 +1032,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>Are You Sure ?</source>
-        <translation>Voc tem certeza?</translation>
+        <translation>Você tem certeza?</translation>
     </message>
     <message>
         <source>Yes</source>
@@ -1040,7 +1040,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>No</source>
-        <translation>No</translation>
+        <translation>Não</translation>
     </message>
 </context>
 <context>
@@ -1055,7 +1055,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>Description:</source>
-        <translation>Descro:</translation>
+        <translation>Descrção:</translation>
     </message>
     <message>
         <source>Add Identity to Contacts List</source>
@@ -1063,7 +1063,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>ok button</source>
-        <translation>boto ok</translation>
+        <translation>botão ok</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1071,7 +1071,7 @@ sending instant messages to your contacts is easy with the RMB. Just click and s
     </message>
     <message>
         <source>cancel button</source>
-        <translation>boto cancel</translation>
+        <translation>botão cancel</translation>
     </message>
     <message>
         <source>Cancel</source>
